@@ -119,7 +119,7 @@ struct _EogScrollViewPrivate {
 	ProgressiveState progressive_state;
 
 	/* how to indicate transparency in images */
-	TransparencyStyle transp_style;
+	EogTransparencyStyle transp_style;
 	guint32 transp_color;
 
 	/* the type of the cursor we are currently showing */
@@ -657,7 +657,7 @@ paint_rectangle (EogScrollView *view, ArtIRect *rect, GdkInterpType interp_type)
 
 	/* Compute transparency parameters */
 	switch (priv->transp_style) {
-	case TRANSP_BACKGROUND: {
+	case EOG_TRANSP_BACKGROUND: {
 		GdkColor color = GTK_WIDGET (priv->display)->style->bg[GTK_STATE_NORMAL];
 
 		check_1 = check_2 = (((color.red & 0xff00) << 8)
@@ -665,12 +665,12 @@ paint_rectangle (EogScrollView *view, ArtIRect *rect, GdkInterpType interp_type)
 				     | ((color.blue & 0xff00) >> 8));
 		break; }
 
-	case TRANSP_CHECKED:
+	case EOG_TRANSP_CHECKED:
 		check_1 = CHECK_GRAY;
 		check_2 = CHECK_LIGHT;
 		break;
 
-	case TRANSP_COLOR:
+	case EOG_TRANSP_COLOR:
 		check_1 = check_2 = priv->transp_color;
 		break;
 
@@ -1215,7 +1215,12 @@ eog_scroll_view_button_press_event (GtkWidget *widget, GdkEventButton *event, gp
 		return FALSE;
 
 	switch (event->button) {
+		case 1:
 		case 2:
+                        if (event->button == 1 && !priv->scroll_wheel_zoom && 
+			    !(event->state & GDK_CONTROL_MASK))
+				break;
+
 			if (is_image_movable (view)) {
 				eog_scroll_view_set_cursor (view, EOG_SCROLL_VIEW_CURSOR_DRAG);
 
@@ -1262,6 +1267,7 @@ eog_scroll_view_button_release_event (GtkWidget *widget, GdkEventButton *event,
 		return FALSE;
 
 	switch (event->button) {
+		case 1:
 		case 2:
 			drag_to (view, event->x, event->y);
 			priv->dragging = FALSE;
@@ -1671,7 +1677,7 @@ eog_scroll_view_set_antialiasing (EogScrollView *view, gboolean state)
 }
 
 void
-eog_scroll_view_set_transparency (EogScrollView *view, TransparencyStyle style, GdkColor *color)
+eog_scroll_view_set_transparency (EogScrollView *view, EogTransparencyStyle style, GdkColor *color)
 {
 	EogScrollViewPrivate *priv;
 	guint32 col = 0;
@@ -1694,7 +1700,7 @@ eog_scroll_view_set_transparency (EogScrollView *view, TransparencyStyle style,
 		changed = TRUE;
 	}
 
-	if (priv->transp_style == TRANSP_COLOR && priv->transp_color != col) {
+	if (priv->transp_style == EOG_TRANSP_COLOR && priv->transp_color != col) {
 		priv->transp_color = col;
 		changed = TRUE;
 	}
@@ -1878,24 +1884,6 @@ eog_scroll_view_set_image (EogScrollView *view, EogImage *image)
 	priv->image = image;
 }
 
-void
-eog_scroll_view_get_image_size   (EogScrollView *view, int *width, int *height, gboolean scaled)
-{
-	EogScrollViewPrivate *priv;
-
-	*width = *height = 0;
-
-	g_return_if_fail (EOG_IS_SCROLL_VIEW (view));
-
-	priv = view->priv;
-
-	if (!priv->pixbuf)
-		return;
-
-	*width = gdk_pixbuf_get_width (priv->pixbuf);
-	*height = gdk_pixbuf_get_height (priv->pixbuf);
-}
-
 gboolean 
 eog_scroll_view_scrollbars_visible (EogScrollView *view)
 {
@@ -1930,7 +1918,7 @@ eog_scroll_view_init (EogScrollView *view)
 	priv->image = NULL;
 	priv->pixbuf = NULL;
 	priv->progressive_state = PROGRESSIVE_NONE;
-	priv->transp_style = TRANSP_BACKGROUND;
+	priv->transp_style = EOG_TRANSP_BACKGROUND;
 	priv->transp_color = 0;
 	priv->cursor = EOG_SCROLL_VIEW_CURSOR_NORMAL;
 }
